==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Constraints for the authenticator
 */
@ApiModel(description = "Constraints for the authenticator")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints.JSON_PROPERTY_AAGUID_GROUPS })
@JsonTypeName("AuthenticatorEnrollmentPolicyAuthenticatorSettings_constraints")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AAGUID_GROUPS = "aaguidGroups";
    private List<String> aaguidGroups = null;

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints() {
    }

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints aaguidGroups(List<String> aaguidGroups) {

        this.aaguidGroups = aaguidGroups;
        return this;
    }

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints addaaguidGroupsItem(String aaguidGroupsItem) {
        if (this.aaguidGroups == null) {
            this.aaguidGroups = new ArrayList<>();
        }
        this.aaguidGroups.add(aaguidGroupsItem);
        return this;
    }

    /**
     * The list of FIDO2 WebAuthn authenticator groups allowed for enrollment
     *
     * @return aaguidGroups
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The list of FIDO2 WebAuthn authenticator groups allowed for enrollment")
    @JsonProperty(JSON_PROPERTY_AAGUID_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getAaguidGroups() {
        return aaguidGroups;
    }

    @JsonProperty(JSON_PROPERTY_AAGUID_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAaguidGroups(List<String> aaguidGroups) {
        this.aaguidGroups = aaguidGroups;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints authenticatorEnrollmentPolicyAuthenticatorSettingsConstraints = (AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints) o;
        return Objects.equals(this.aaguidGroups,
                authenticatorEnrollmentPolicyAuthenticatorSettingsConstraints.aaguidGroups);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(aaguidGroups);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints {\n");
        sb.append("    aaguidGroups: ").append(toIndentedString(aaguidGroups)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Constraints for the authenticator
 */
@ApiModel(description = "Constraints for the authenticator")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints.JSON_PROPERTY_AAGUID_GROUPS })
@JsonTypeName("AuthenticatorEnrollmentPolicyAuthenticatorSettings_constraints")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AAGUID_GROUPS = "aaguidGroups";
    private List<String> aaguidGroups = null;

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints() {
    }

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints aaguidGroups(List<String> aaguidGroups) {

        this.aaguidGroups = aaguidGroups;
        return this;
    }

    public AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints addaaguidGroupsItem(String aaguidGroupsItem) {
        if (this.aaguidGroups == null) {
            this.aaguidGroups = new ArrayList<>();
        }
        this.aaguidGroups.add(aaguidGroupsItem);
        return this;
    }

    /**
     * The list of FIDO2 WebAuthn authenticator groups allowed for enrollment
     *
     * @return aaguidGroups
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The list of FIDO2 WebAuthn authenticator groups allowed for enrollment")
    @JsonProperty(JSON_PROPERTY_AAGUID_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getAaguidGroups() {
        return aaguidGroups;
    }

    @JsonProperty(JSON_PROPERTY_AAGUID_GROUPS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAaguidGroups(List<String> aaguidGroups) {
        this.aaguidGroups = aaguidGroups;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints authenticatorEnrollmentPolicyAuthenticatorSettingsConstraints = (AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints) o;
        return Objects.equals(this.aaguidGroups,
                authenticatorEnrollmentPolicyAuthenticatorSettingsConstraints.aaguidGroups);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(aaguidGroups);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyAuthenticatorSettingsConstraints {\n");
        sb.append("    aaguidGroups: ").append(toIndentedString(aaguidGroups)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
